@@ -81,7 +81,8 @@ def proc_background(
 def proc_slider(
         image_dir: str,
         out_path: str = None,
-        white_value: int = 255
+        white_value: int = 255,
+        alpha_white_max: int = None  # 透明度通道为白色的最大值
 ):
     """
     处理滑块图片
@@ -90,6 +91,7 @@ def proc_slider(
     :param image_dir:
     :param out_path:
     :param white_value:
+    :param alpha_white_max: 透明度通道为白色的最大值，例如：15
     :return:
     """
     image_file_name = image_dir.split(path_separator)[-1:][0]  # 获取图片文件名
@@ -105,19 +107,28 @@ def proc_slider(
         pass
     proc_file_dir = "%s%s%s" % (out_path, path_separator, image_proc_file_name)
 
-    image = cv2.imread(image_dir)  # 这个时候还是三个值，需要灰值化
-    image_gray = cv2.cvtColor(image, cv2.COLOR_BGR2GRAY)  # 灰值化
-    height = image_gray.shape[0]  # 高
-    weight = image_gray.shape[1]  # 宽
+    if alpha_white_max is not None:
+        image = cv2.imread(image_dir, cv2.IMREAD_UNCHANGED)  # 4个通道
+    else:
+        image = cv2.imread(image_dir)  # 灰度
+        image = cv2.cvtColor(image, cv2.COLOR_BGR2GRAY)  # 灰度
+    height = image.shape[0]  # 高
+    weight = image.shape[1]  # 宽
 
     for each_height in range(height):
         for each_weight in range(weight):
-            if image_gray[each_height, each_weight] >= white_value:
-                image_gray[each_height, each_weight] = 255  # 判定为最白区域的，直接改为白色
+            if alpha_white_max is not None:
+                if image[each_height, each_weight][3] <= 15:
+                    image[each_height, each_weight] = 255  # 判定为最白区域的，直接改为白色
+                else:
+                    image[each_height, each_weight] = 0  # 其他区域直接改为黑色
             else:
-                image_gray[each_height, each_weight] = 0  # 其他区域直接改为黑色
+                if image[each_height, each_weight] >= white_value:
+                    image[each_height, each_weight] = 255  # 判定为最白区域的，直接改为白色
+                else:
+                    image[each_height, each_weight] = 0  # 其他区域直接改为黑色
 
-    cv2.imwrite(proc_file_dir, image_gray)
+    cv2.imwrite(proc_file_dir, image)
     return proc_file_dir
 
 
